# coding: utf-8

"""
    Trinsic API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from trinsic_api.api.well_known_api import WellKnownApi


class TestWellKnownApi(unittest.TestCase):
    """WellKnownApi unit test stubs"""

    def setUp(self) -> None:
        self.api = WellKnownApi()

    def tearDown(self) -> None:
        pass

    def test_interac_jwk(self) -> None:
        """Test case for interac_jwk

        """
        pass


if __name__ == '__main__':
    unittest.main()
