# coding: utf-8

"""
    Trinsic API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from trinsic_api.models.refresh_step_content_response import RefreshStepContentResponse

class TestRefreshStepContentResponse(unittest.TestCase):
    """RefreshStepContentResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RefreshStepContentResponse:
        """Test RefreshStepContentResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RefreshStepContentResponse`
        """
        model = RefreshStepContentResponse()
        if include_optional:
            return RefreshStepContentResponse(
                next_step = trinsic_api.models.integration_step.IntegrationStep(
                    method = LaunchBrowser, 
                    content = 'https://api.trinsic.id/api/session/launch?clientToken=...', 
                    refresh = null, )
            )
        else:
            return RefreshStepContentResponse(
                next_step = trinsic_api.models.integration_step.IntegrationStep(
                    method = LaunchBrowser, 
                    content = 'https://api.trinsic.id/api/session/launch?clientToken=...', 
                    refresh = null, ),
        )
        """

    def testRefreshStepContentResponse(self):
        """Test RefreshStepContentResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
