# coding: utf-8

"""
    Trinsic API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from trinsic_api.models.provider_contract import ProviderContract

class TestProviderContract(unittest.TestCase):
    """ProviderContract unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ProviderContract:
        """Test ProviderContract
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ProviderContract`
        """
        model = ProviderContract()
        if include_optional:
            return ProviderContract(
                id = 'ca-mdl',
                name = 'CA DMV',
                description = 'dmv.ca.gov',
                logo_url = 'https://content.trinsic.id/connect/integrations/ca-dmv.png',
                available = True,
                geography = ["CA"],
                regions = ["United States"],
                launch_method = 'LaunchBrowser',
                collection_method = 'PollResult',
                results_may_be_delayed_after_redirect = False,
                has_refreshable_content = False,
                requires_input = False,
                has_trinsic_interface = True,
                supports_advanced_provider_sessions = True,
                sub_providers = [
                    trinsic_api.models.sub_provider_metadata.SubProviderMetadata(
                        id = '', 
                        name = '', 
                        description = '', 
                        logo_url = '', )
                    ],
                status = 'Online'
            )
        else:
            return ProviderContract(
                id = 'ca-mdl',
                name = 'CA DMV',
                description = 'dmv.ca.gov',
                logo_url = 'https://content.trinsic.id/connect/integrations/ca-dmv.png',
                available = True,
                geography = ["CA"],
                regions = ["United States"],
                launch_method = 'LaunchBrowser',
                collection_method = 'PollResult',
                results_may_be_delayed_after_redirect = False,
                has_refreshable_content = False,
                requires_input = False,
                has_trinsic_interface = True,
                supports_advanced_provider_sessions = True,
                status = 'Online',
        )
        """

    def testProviderContract(self):
        """Test ProviderContract"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
