# coding: utf-8

"""
    Trinsic API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from trinsic_api.models.nigeria_nin_input import NigeriaNinInput

class TestNigeriaNinInput(unittest.TestCase):
    """NigeriaNinInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> NigeriaNinInput:
        """Test NigeriaNinInput
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `NigeriaNinInput`
        """
        model = NigeriaNinInput()
        if include_optional:
            return NigeriaNinInput(
                first_name = '0',
                middle_name = '',
                last_name = '0',
                phone_number = '',
                date_of_birth = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                gender = '',
                national_id_number = '4807288800152802179809012345678910'
            )
        else:
            return NigeriaNinInput(
                first_name = '0',
                last_name = '0',
                date_of_birth = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                national_id_number = '4807288800152802179809012345678910',
        )
        """

    def testNigeriaNinInput(self):
        """Test NigeriaNinInput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
