# coding: utf-8

"""
    Trinsic API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from trinsic_api.models.result_collection_method import ResultCollectionMethod

class TestResultCollectionMethod(unittest.TestCase):
    """ResultCollectionMethod unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testResultCollectionMethod(self):
        """Test ResultCollectionMethod"""
        # inst = ResultCollectionMethod()

if __name__ == '__main__':
    unittest.main()
